==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5fmk.h <==
// public class gnu.java.locale.LocaleInformation_mk

// class file dependencies
// @dep_class ba6c0dbb4ba4fc75 gnu_java_locale_LocaleInformation__5fmk
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fmk_H_
#define _JC_gnu_java_locale_LocaleInformation__5fmk_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fmk$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fmk$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$refs	_jc_gnu_java_locale_LocaleInformation__5fmk$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fmk$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$object	_jc_gnu_java_locale_LocaleInformation__5fmk$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fmk$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fmk$vmethods	_jc_gnu_java_locale_LocaleInformation__5fmk$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fmk$vtable	_jc_gnu_java_locale_LocaleInformation__5fmk$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fmk$vtype	_jc_gnu_java_locale_LocaleInformation__5fmk$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fmk$fields_struct {
	_jc_object_array	*contents;
	struct _jc_java_util_Hashtable$object	*currenciesDisplayName;
	struct _jc_java_lang_String$object	*currenciesDisplayNameKeys;
	struct _jc_java_lang_String$object	*currenciesDisplayNameValues;
	struct _jc_java_util_Hashtable$object	*currenciesSymbol;
	struct _jc_java_lang_String$object	*currenciesSymbolKeys;
	struct _jc_java_lang_String$object	*currenciesSymbolValues;
	_jc_object_array	*eras;
	struct _jc_java_util_Hashtable$object	*languages;
	struct _jc_java_lang_String$object	*languagesKeys;
	struct _jc_java_lang_String$object	*languagesValues;
	_jc_object_array	*months;
	_jc_object_array	*shortMonths;
	_jc_object_array	*shortWeekdays;
	struct _jc_java_util_Hashtable$object	*territories;
	struct _jc_java_lang_String$object	*territoriesKeys;
	struct _jc_java_lang_String$object	*territoriesValues;
	_jc_object_array	*weekdays;
};
extern _jc_gnu_java_locale_LocaleInformation__5fmk$fields_struct _jc_gnu_java_locale_LocaleInformation__5fmk$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fmk$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fmk$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fmk$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fmk$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fmk$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fmk$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fmk$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fmk$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fmk$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fmk$vmethods	gnu_java_locale_LocaleInformation__5fmk;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fmk$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fmk$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fmk$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fmk$refs {
    _jc_gnu_java_locale_LocaleInformation__5fmk$sub_refs	gnu_java_locale_LocaleInformation__5fmk;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fmk$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fmk$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fmk$sub_nonrefs	gnu_java_locale_LocaleInformation__5fmk;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fmk$object {
	_jc_gnu_java_locale_LocaleInformation__5fmk$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fmk$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fmk$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fmk$vtype _jc_gnu_java_locale_LocaleInformation__5fmk$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fmk, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fmk$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fmk_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5fmk.h <==
// public class gnu.java.locale.LocaleInformation_mk

// class file dependencies
// @dep_class 1976760fcb082e6 gnu_java_locale_LocaleInformation__5fmk
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fmk_H_
#define _JC_gnu_java_locale_LocaleInformation__5fmk_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fmk$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fmk$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$refs	_jc_gnu_java_locale_LocaleInformation__5fmk$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fmk$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$object	_jc_gnu_java_locale_LocaleInformation__5fmk$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fmk$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fmk$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fmk$vmethods	_jc_gnu_java_locale_LocaleInformation__5fmk$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fmk$vtable	_jc_gnu_java_locale_LocaleInformation__5fmk$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fmk$vtype	_jc_gnu_java_locale_LocaleInformation__5fmk$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fmk$fields_struct {
	_jc_object_array	*contents;
	struct _jc_java_util_Hashtable$object	*currenciesDisplayName;
	struct _jc_java_lang_String$object	*currenciesDisplayNameKeys;
	struct _jc_java_lang_String$object	*currenciesDisplayNameValues;
	struct _jc_java_util_Hashtable$object	*currenciesSymbol;
	struct _jc_java_lang_String$object	*currenciesSymbolKeys;
	struct _jc_java_lang_String$object	*currenciesSymbolValues;
	_jc_object_array	*eras;
	struct _jc_java_util_Hashtable$object	*languages;
	struct _jc_java_lang_String$object	*languagesKeys;
	struct _jc_java_lang_String$object	*languagesValues;
	_jc_object_array	*months;
	_jc_object_array	*shortMonths;
	_jc_object_array	*shortWeekdays;
	struct _jc_java_util_Hashtable$object	*territories;
	struct _jc_java_lang_String$object	*territoriesKeys;
	struct _jc_java_lang_String$object	*territoriesValues;
	_jc_object_array	*weekdays;
};
extern _jc_gnu_java_locale_LocaleInformation__5fmk$fields_struct _jc_gnu_java_locale_LocaleInformation__5fmk$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fmk$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fmk$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fmk$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fmk$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fmk$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fmk$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fmk$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fmk$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fmk$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fmk$vmethods	gnu_java_locale_LocaleInformation__5fmk;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fmk$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fmk$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fmk$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fmk$refs {
    _jc_gnu_java_locale_LocaleInformation__5fmk$sub_refs	gnu_java_locale_LocaleInformation__5fmk;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fmk$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fmk$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fmk$sub_nonrefs	gnu_java_locale_LocaleInformation__5fmk;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fmk$object {
	_jc_gnu_java_locale_LocaleInformation__5fmk$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fmk$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fmk$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fmk$vtype _jc_gnu_java_locale_LocaleInformation__5fmk$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fmk, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fmk$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fmk_H_ */
